---

slug: /operator-overview
---

# Overview of operators

Operators are generally used to connect operands or parameters and return results. Syntactically, operators can appear before, after, or between operands.

Common operators can be divided into unary and binary operators:

* Unary operators

  Unary operators operate on a single operand. The common format for unary operators is as follows:

  ```sql
  Operator operand
  ```

* Binary operators

  Binary operators operate on two operands. The common format for binary operators is as follows:

  ```sql
  operand1 operator operand2
  ```

  :::info

  * Other operators with special formats can accept more than two operands.
  * If an operator is provided with a `NULL` operand, the result is always `NULL`. The only exception is the character concatenation operator (||).

  :::

seekdb currently supports the following operators:

* [Arithmetic operators](../200.operator/300.arithmetic-operators.md)

* [Bitwise operators](../200.operator/400.bitwise-operators.md)

* [Comparison operators](../200.operator/500.comparison-operators.md)

* [Logical operators](../200.operator/600.logical-operators.md)

* [Date and time operators](../200.operator/800.date-and-time-operators.md)

* [Character concatenation operators](../200.operator/900.character-concatenation-operators.md)